@@ -18,20 +18,21 @@
 #' 
 #' If you have a function with same name as your package, that will change as well.
 #' 
-#' It is strongly recommended to have a backup backup before proceeding.
+#' It is strongly recommended to make backups before proceeding.
 #' 
 #' Inspired by Nick Tierney's blog post: https://www.njtierney.com/post/2017/10/27/change-pkg-name/
 #' 
 #' @param path Path of the package.
 #' @param new_name Desired name of the package.
 #' @param check_validity Check first if the package name is valid and available by running the 
-#' function \code{available} from the package \code{available} Default is TRUE.
+#' function \code{available} from the package \code{available} Default is TRUE. This will prompt a warning about
+#' potentially offensive results from Urban Dictionary which is used to check the validity of the package name.
 #' @param change_git If \code{TRUE} (default), changes the remote url of the remote. Note that
 #' you still need to change the name of the GitHub repository manually as follows: 
 #' Go to the URL of your Github package, click Settings, change the name under "Repository name", and click Rename.
 #' @param run_roxygen Should the package documentation be updated via roxygen? If \code{TRUE}, removes all old \code{Rd} files 
 #' in \code{man} directory.
-#' @param remote_name Name of the remote. Defaults to \code{git2r::remotes(repo)[1]}.
+#' @param remote_name Name of the remote. Defaults to \code{git2r::remotes(path)[1]}.
 #' @param ask Ask confirmation before starting the rename process. Default is TRUE.
 #' @export
 #' @examples 
@@ -46,6 +47,7 @@
 #' 
 changer <- function(path, new_name, check_validity = TRUE, change_git = TRUE, run_roxygen = FALSE, remote_name = NULL, ask = TRUE) {
   
+  path <- normalizePath(path)
   if (!file.exists(f <- path)) 
     stop(paste0("Path '", f, "' does not exist. "))
   
@@ -65,6 +67,10 @@ changer <- function(path, new_name, check_validity = TRUE, change_git = TRUE, ru
   if (file.exists(new_path <- file.path(dir_path, new_name))) 
     stop(paste0("Path '", new_path, "' already exists. "))
   
+  # check that the path actually contains R package
+  if(!file.exists(paste0(path, "/DESCRIPTION")))
+    stop("The path does not seem point to an R package as there is no DESCRIPTION file present.")
+  
   # all files and dirs:
   R_files <- list.files(path, all.files = TRUE, recursive = TRUE, include.dirs = FALSE, 
                         ignore.case = TRUE, full.names = TRUE, pattern = "\\R$")
@@ -76,8 +82,10 @@ changer <- function(path, new_name, check_validity = TRUE, change_git = TRUE, ru
                            full.names = TRUE, pattern = "\\.stan$")
   md_files <- list.files(path, all.files = TRUE, recursive = TRUE, include.dirs = FALSE, 
                          full.names = TRUE, pattern = "\\.(md|Rmd|Rnw|html|bib)$")
+  yml_files <- list.files(path, all.files = TRUE, recursive = TRUE, include.dirs = FALSE, 
+                         full.names = TRUE, pattern = "\\.(yml|yaml)$")
   
-  files <- c(R_files, c_or_cpp_files, fortran_files, stan_files, md_files, 
+  files <- c(R_files, c_or_cpp_files, fortran_files, stan_files, md_files, yml_files,
              file.path(path, "DESCRIPTION"), file.path(path, "NAMESPACE"),
              if (file.exists(f <- file.path(path, ".Rbuildignore"))) f, 
              if (file.exists(f <- file.path(path, ".gitignore"))) f,
@@ -153,7 +161,13 @@ changer <- function(path, new_name, check_validity = TRUE, change_git = TRUE, ru
   if (file.exists(f <- file.path(path, "R", paste0(old_name, "-deprecated.R")))) {
     file.rename(f, file.path(path, "R", paste0(new_name, "-deprecated.R")))
   }
-  
+  if (file.exists(f <- file.path(path,  paste0(old_name, ".yml")))) {
+    file.rename(f, file.path(path,  paste0(new_name, ".yml")))
+  }
+  if (file.exists(f <- file.path(path,  paste0(old_name, ".yaml")))) {
+    file.rename(f, file.path(path,  paste0(new_name, ".yaml")))
+  }
+             
   if (run_roxygen) {
     # remove old Rd files
     Rd_files <- list.files(file.path(path, "man"), pattern = "\\.(Rd)$", full.names = TRUE)
@@ -172,6 +186,11 @@ changer <- function(path, new_name, check_validity = TRUE, change_git = TRUE, ru
     file.remove(f)
   }
   
+  # warning on detecting rda files in data
+  if (file.exists(f <- file.path(path, "data", paste0(old_name, ".rda")))) {
+    warning(".rda files were detected in data/. Load and resave these files.")
+  }
+             
   # rename directory
 
   if (.Platform$OS.type == "windows") {
